
Installation
============


To install the latest stable release via pip, run:

.. code-block:: bash

    $ pip install Flask-Authorize


Alternatively with easy_install, run:

.. code-block:: bash

    $ easy_install Flask-Authorize


To install the bleeding-edge version of the project:

.. code-block:: bash

    $ git clone http://github.com/bprinty/Flask-Authorize.git
    $ cd Flask-Authorize
    $ python setup.py install
